@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,9 +21,12 @@
 
 #include "../config.h"
 
-int buffer2array(char * buffer, char *** array);
-
-void freeArgArray(char ** array, int argArrayLength);
+/* tokenizes up to max elements in buffer (a null-terminated string) and
+ * stores the result in array (which must be capable of holding up to
+ * max elements).  Tokenization is based on C string quoting rules.
+ * The arguments buffer and array are modified.
+ * Returns the number of elements tokenized.
+ */
+int buffer2array(char *buffer, char *array[], const int max);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
