@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,50 +24,51 @@
 #include "song.h"
 #include "list.h"
 
-#include <stdio.h>
-#include <sys/param.h>
+typedef List DirectoryList;
 
-extern char * directory_db;
+typedef struct _DirectoryStat {
+	ino_t inode;
+	dev_t device;
+} DirectoryStat;
 
-void readDirectoryDBIfUpdateIsFinished();
+typedef struct _Directory {
+	char *path;
+	DirectoryList *subDirectories;
+	SongList *songs;
+	struct _Directory *parent;
+	DirectoryStat *stat;
+} Directory;
 
-void clearUpdatePid();
+void readDirectoryDBIfUpdateIsFinished(void);
 
-int isUpdatingDB();
+int isUpdatingDB(void);
 
 void directory_sigChldHandler(int pid, int status);
 
-int updateInit(FILE * fp, List * pathList);
+int updateInit(int fd, List * pathList);
 
-void initMp3Directory();
+void initMp3Directory(void);
 
-void closeMp3Directory();
+void closeMp3Directory(void);
 
-int printDirectoryInfo(FILE * fp, char * dirname);
+int printDirectoryInfo(int fd, char *dirname);
 
-int writeDirectoryDB();
+int checkDirectoryDB(void);
 
-int readDirectoryDB();
+int writeDirectoryDB(void);
 
-void updateMp3Directory();
+int readDirectoryDB(void);
 
-int printAllIn(FILE * fp, char * name);
+void updateMp3Directory(void);
 
-int addAllIn(FILE * fp, char * name);
+Song *getSongFromDB(char *file);
 
-int printInfoForAllIn(FILE * fp, char * name);
+time_t getDbModTime(void);
 
-int searchForSongsIn(FILE * fp, char * name, char * item, char * string);
+int traverseAllIn(int fd, char *name,
+		  int (*forEachSong) (int, Song *, void *),
+		  int (*forEachDir) (int, Directory *, void *), void *data);
 
-int findSongsIn(FILE * fp, char * name, char * item, char * string);
-
-int countSongsIn(FILE * fp, char * name);
-
-unsigned long sumSongTimesIn(FILE * fp, char * name);
-
-Song * getSongFromDB(char * file);
-
-time_t getDbModTime();
+#define getDirectoryPath(dir) ((dir && dir->path) ? dir->path : "")
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
