@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,14 +21,14 @@
 
 #include "inputStream.h"
 
-void inputStream_initFile();
+void inputStream_initFile(void);
 
-int inputStream_fileOpen(InputStream * inStream, char * filename);
+int inputStream_fileOpen(InputStream * inStream, char *filename);
 
 int inputStream_fileSeek(InputStream * inStream, long offset, int whence);
 
-size_t inputStream_fileRead(InputStream * inStream, void * ptr, size_t size, 
-		size_t nmemb);
+size_t inputStream_fileRead(InputStream * inStream, void *ptr, size_t size,
+			    size_t nmemb);
 
 int inputStream_fileClose(InputStream * inStream);
 
@@ -37,4 +37,3 @@ int inputStream_fileAtEOF(InputStream * inStream);
 int inputStream_fileBuffer(InputStream * inStream);
 
 #endif
-/* vim:set shiftwidth=8 tabstop=8 expandtab: */
