@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,11 +21,19 @@
 
 #include "../config.h"
 
-extern int listenSocket;
+#include <sys/time.h>
+#include <sys/types.h>
+#include <unistd.h>
+#include <sys/select.h>
 
-int establish(unsigned short port);
+void listenOnPort(void);
 
-void getConnections(int sock);
+void getConnections(fd_set * fds);
+
+void closeAllListenSockets(void);
+void freeAllListenSockets(void);
+
+/* fdmax should be initialized to something */
+void addListenSocketsToFdSet(fd_set * fds, int *fdmax);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
