@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 
 #include "../config.h"
 
-#include "inputPlugin.h" 
+#include "inputPlugin.h"
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -29,28 +29,24 @@
 #include <unistd.h>
 #include <time.h>
 
-int lsPlaylists(FILE * fp, char * utf8path);
+int lsPlaylists(int fd, char *utf8path);
 
-char * getSuffix(char * utf8file);
+char *getSuffix(char *utf8file);
 
-int isValidRemoteUtf8Url(char * utf8url);
+int isValidRemoteUtf8Url(char *utf8url);
 
-int isRemoteUrl(char * url);
+int isRemoteUrl(char *url);
 
-int myStat(char * utf8file, struct stat * st);
+int myStat(char *utf8file, struct stat *st);
 
-int isFile(char * utf8file, time_t * mtime);
+int isDir(char *utf8name);
 
-int isDir(char * utf8name);
+int isPlaylist(char *utf8file);
 
-int isPlaylist(char * utf8file);
+InputPlugin *hasMusicSuffix(char *utf8file, unsigned int next);
 
-InputPlugin * hasMusicSuffix(char * utf8file);
+InputPlugin *isMusic(char *utf8file, time_t * mtime, unsigned int next);
 
-InputPlugin * isMusic(char * utf8file, time_t * mtime);
-
-char * dupAndStripPlaylistSuffix(char * file);
-
-int printRemoteUrlHandlers(FILE * fp);
+int printRemoteUrlHandlers(int fd);
 
 #endif
