@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,14 +20,12 @@
 #define MYFPRINTF_H
 
 #include "../config.h"
+#include "gcc.h"
 
+#include <stdarg.h>
 #include <stdio.h>
 
-void myfprintfStdLogMode(FILE * out, FILE * err, char * outFilename,
-                char * errFilename);
-
-void myfprintf(FILE * fp, char * format, ... );
-
-int myfprintfCloseAndOpenLogFile();
+mpd_fprintf void fdprintf(const int fd, const char *fmt, ...);
+void vfdprintf(const int fd, const char *fmt, va_list arglist);
 
 #endif
