@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
  */
 
 #ifndef PCM_UTILS_H
-#define PMC_UTILS_H
+#define PCM_UTILS_H
 
 #include "../config.h"
 
@@ -25,18 +25,16 @@
 
 #include <stdlib.h>
 
-void pcm_changeBufferEndianness(char * buffer, int bufferSize, int bits);
+void pcm_volumeChange(char *buffer, int bufferSize, AudioFormat * format,
+		      int volume);
 
-void pcm_volumeChange(char * buffer, int bufferSize, AudioFormat * format,
-		int volume);
+void pcm_mix(char *buffer1, char *buffer2, size_t bufferSize1,
+	     size_t bufferSize2, AudioFormat * format, float portion1);
 
-void pcm_mix(char * buffer1, char * buffer2, size_t bufferSize1, 
-		size_t bufferSize2, AudioFormat * format, float portion1);
-
-void pcm_convertAudioFormat(AudioFormat * inFormat, char * inBuffer, size_t
-                inSize, AudioFormat * outFormat, char * outBuffer);
+void pcm_convertAudioFormat(AudioFormat * inFormat, char *inBuffer, size_t
+			    inSize, AudioFormat * outFormat, char *outBuffer);
 
 size_t pcm_sizeOfOutputBufferForAudioFormatConversion(AudioFormat * inFormat,
-		char * inBuffer, size_t inSize, AudioFormat * outFormat);
+						      size_t inSize,
+						      AudioFormat * outFormat);
 #endif
-/* vim:set shiftwidth=8 tabstop=8 expandtab: */
