@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,18 +21,19 @@
 
 #include "../config.h"
 
-#define PERMISSION_READ		1
-#define PERMISSION_ADD		2
-#define PERMISSION_CONTROL	4
-#define PERMISSION_ADMIN	8
+#define PERMISSION_NONE    0
+#define PERMISSION_READ    1
+#define PERMISSION_ADD     2
+#define PERMISSION_CONTROL 4
+#define PERMISSION_ADMIN   8
 
-void initPermissions();
 
-int getPermissionFromPassword(char * password, unsigned int * permission);
+int getPermissionFromPassword(char *password, int *permission);
 
-void finishPermissions();
+void finishPermissions(void);
 
-unsigned int getDefaultPermissions();
+int getDefaultPermissions(void);
+
+void initPermissions(void);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
