@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,13 +37,13 @@ typedef struct _PlayerData {
 	OutputBuffer buffer;
 	PlayerControl playerControl;
 	DecoderControl decoderControl;
+	mpd_uint8 *audioDeviceStates;
 } PlayerData;
 
-void initPlayerData();
+void initPlayerData(void);
 
-PlayerData * getPlayerData();
+PlayerData *getPlayerData(void);
 
-void freePlayerData();
+void freePlayerData(void);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
