@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * (c)2004 replayGain code by AliasMrJones
  * This project's homepage is: http://www.musicpd.org
  *
@@ -26,13 +26,25 @@
 #define REPLAYGAIN_TRACK	1
 #define REPLAYGAIN_ALBUM	2
 
-void initReplayGainState();
+extern int replayGainState;
 
-int getReplayGainState();
+typedef struct _ReplayGainInfo {
+	float albumGain;
+	float albumPeak;
+	float trackGain;
+	float trackPeak;
 
-float computeReplayGainScale(float gain, float peak);
+	/* used internally by mpd, to mess with it */
+	float scale;
+} ReplayGainInfo;
 
-void doReplayGain(char * buffer, int bufferSize, AudioFormat * format, 
-		float scale);
+ReplayGainInfo *newReplayGainInfo(void);
+
+void freeReplayGainInfo(ReplayGainInfo * info);
+
+void initReplayGainState(void);
+
+void doReplayGain(ReplayGainInfo * info, char *buffer, int bufferSize,
+		  AudioFormat * format);
 
 #endif
