@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,21 +21,22 @@
 
 #include "../config.h"
 
-int handlePendingSignals();
+int handlePendingSignals(void);
 
-void initSigHandlers();
+void initSigHandlers(void);
 
-void finishSigHandlers();
+void finishSigHandlers(void);
 
-void ignoreSignals();
+void setSigHandlersForDecoder(void);
 
-void blockSignals();
+void ignoreSignals(void);
 
-void unblockSignals();
+void blockSignals(void);
 
-void blockTermSignal();
+void unblockSignals(void);
 
-void unblockTermSignal();
+void blockTermSignal(void);
+
+void unblockTermSignal(void);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
