@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,14 +28,13 @@ typedef struct _Stats {
 	int numberOfSongs;
 	unsigned long dbPlayTime;
 	/*unsigned long playTime;
-	unsigned long songsPlayed;*/
+	   unsigned long songsPlayed; */
 } Stats;
 
 extern Stats stats;
 
-void initStats();
+void initStats(void);
 
-int printStats(FILE * fp);
+int printStats(int fd);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
