@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,11 +19,10 @@
 #ifndef UTF_8_H
 #define UTF_8_H
 
-unsigned char * latin1StrToUtf8Dup(unsigned char * latin1);
+char *latin1StrToUtf8Dup(char *latin1);
 
-unsigned char * utf8StrToLatin1Dup(unsigned char * utf8);
+char *utf8StrToLatin1Dup(char *utf8);
 
-int validUtf8String(unsigned char * string);
+int validUtf8String(char *string);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
