@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,15 +27,18 @@
 #define VOLUME_MIXER_ALSA	"alsa"
 #define VOLUME_MIXER_SOFTWARE	"software"
 
-void initVolume();
+void initVolume(void);
 
-void openVolumeDevice();
+void openVolumeDevice(void);
 
-void finishVolume();
+void finishVolume(void);
 
-int getVolumeLevel();
+int getVolumeLevel(void);
 
-int changeVolumeLevel(FILE * fp, int change, int rel);
+int changeVolumeLevel(int fd, int change, int rel);
+
+void read_sw_volume_state(FILE *fp);
+
+void save_sw_volume_state(FILE *fp);
 
 #endif
-/* vim:set shiftwidth=4 tabstop=8 expandtab: */
